%{!?kernel_version: %{expand: %%define kernel_version %(uname -r)}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | perl -pe 's/^.*el5(.*?)$/$1/g'|sed -e 's/^$/smp/g')}}

# On RHEL 5, smp type has no tag
%if "%{type}" != "smp"
%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}%{type}
%else
%define releasetag %{kversionreltag}
%define kernel_dir %{kernel_version}
%endif

# Definitions for symvers files.
%define vmw_symvers_dir etc/vmware-tools/symvers
%define bld_symvers_file Module.symvers

Name:         vmware-tools-vsock
BuildRequires: kernel-devel redhat-rpm-config gcc make perl
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vsock kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.0.0.0
Source1:      vsock-configModule.tar.gz
BuildRoot:    %{_tmppath}/%{name}-%{version}-build

# We define this so our source packages don't contain kernel version in the release
# field but the resulting binary kmod packages they build do.  Only
# necessary on RHEL.
%{?vmw_release:Release:   %{vmw_release}.el5}
%{!?vmw_release:Release:   %{kversionreltag}.4.el5}

Source0:      vsock.tar
Source2:      vsock-vmware-PLDP-spec

%define kernel_version %(uname -r|perl -pe 's/^(.*el5).*$/$1/g')

# Make sure redhat-rpm-config is installed or the
# kernel_module_package macro will throw an error rather than a nice message
%{!?kernel_module_package: You must have the redhat-rpm-config package installed to build this package.}

%define vmware_use_symvers_file 1

# RHEL 5 defines the architecture as i386 by default, even though it's
# an i686 system with i686 kernels.  Define the _arch and _target_cpu
# defaults here so the user doesn't have to specify them on the
# command line
%ifarch i386
%define _arch i686
%define _target_cpu i686
%endif

# Lock down flavors to build to just the current flavor.
%{expand: %%define current_flavor %(uname -r|perl -pe 's/^.*\.el5(.*)$/$1/g'|perl -pe 's/^$/default/g')}
%kernel_module_package -s %{SOURCE2} %{current_flavor}

%prep
%setup -n vsock-only

# XXX: We will need to handle the .symvers file for modules
# XXX: with dependent builds.
%build
for flavor in %flavors_to_build; do
  VMCI_SYMVERS_FILE=/%{vmw_symvers_dir}/vmci-9.0.4.0-%{kernel_version}-$flavor

  make clean
  rm -rf ../$flavor ../vsock.o
  # For modules that depend on vmci, copy in the vmci symvers file
  # or die trying.
  # XXX: I can only handle dependency on one module's symvers file.
  if [ "vsock" = "vsock" -o "vsock" = "vmhgfs" ]; then
     if [ ! -e $VMCI_SYMVERS_FILE ]; then
        echo
        echo
        echo "
ERROR: Could not find $VMCI_SYMVERS_FILE.  This package relies on kernel symbols for the currently running kernel that are built from the vmware-tools-vmci source RPM package.  Please do the following:

- Rebuild the vmware-tools-vmci source RPM package.
- Install the resulting binary RPM from /usr/src/redhat/RPMS/\$ARCH/.
- Rebuild this package again."
        echo
        echo
        exit 1
     fi
     cp -f $VMCI_SYMVERS_FILE ./%{bld_symvers_file}
  fi

  # Build it!
  make
  mkdir ../$flavor
  cp ../vsock.o ../$flavor
  # Take the symvers file with us as well.
  cp ./%{bld_symvers_file} ../$flavor/%{bld_symvers_file}
done

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
for flavor in %flavors_to_build; do
  vsock_SYMVERS_FILE=%{vmw_symvers_dir}/vsock-1.0.0.0-%{kernel_version}-$flavor
  if [ "$flavor" = "default" ]; then
     flavortag=""
  else
     flavortag="$flavor"
  fi
  # Install the module and symvers file.
  install -m 644 -D ../$flavor/vsock.o $RPM_BUILD_ROOT/lib/modules/%{kernel_version}${flavortag}/extra/%{name}/vsock.ko
  install -m 644 -D ../$flavor/%{bld_symvers_file} $RPM_BUILD_ROOT/$vsock_SYMVERS_FILE
done
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vsock.  The vsock kernel module provides an interface similar to the Berkeley UNIX sockets interface for using the vmci device. The vsock module allows for socket based communication between processes in the virtual machine and on the host, as well as between processes in different virtual machines.

%package common
Summary:      Contains the common files used by all the vsock kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.0
Release:      4.el5
Version:      8.6.14

%description common
 This package contains the common system configuration and scripts responsible for loading the vsock kernel module.  The vsock kernel module provides an interface similar to the Berkeley UNIX sockets interface for using the vmci device. The vsock module allows for socket based communication between processes in the virtual machine and on the host, as well as between processes in different virtual machines.

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vsock ]; then
      /sbin/chkconfig vsock off
   fi
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl --os=linux,rhel,5 --kernel=%{kernel_version} --toDeconfigure=vsock
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,rhel,5 --dbDelAnswer VSOCK_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,rhel,5 --dbAddAnswer VSOCK_NAME,vsock
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-config.pl --os=linux,rhel,5 --kernel=%{kernel_version} --toConfigure=vsock
if [ -e /etc/init.d/vsock ]; then
   /sbin/chkconfig vsock on
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vsock ]; then
      /sbin/chkconfig vsock off
   fi
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl --os=linux,rhel,5 --kernel=%{kernel_version} --toDeconfigure=vsock
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,rhel,5 --dbDelAnswer VSOCK_NAME
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-config.pl
/etc/rc.d/init.d/vsock

